import { useEffect, useState } from 'react';
import { useFramework } from '../useFramework';
export const useAppConfig = (args) => {
    const { appKey } = args;
    const provider = useFramework().modules.app;
    const [value, setValue] = useState();
    const [error, setError] = useState();
    const [isLoading, setIsLoading] = useState(false);
    useEffect(() => {
        setValue(undefined);
    }, [setValue, appKey]);
    useEffect(() => {
        if (!appKey) {
            return;
        }
        setIsLoading(true);
        const request = provider.getAppConfig(appKey).subscribe({
            next: (value) => setValue(value),
            error: (err) => setError(err),
            complete: () => setIsLoading(false),
        });
        return () => {
            setIsLoading(false);
            request.unsubscribe();
        };
    }, [provider, setValue, setError, setIsLoading, appKey]);
    return { value, error, isLoading };
};
export default useAppConfig;
//# sourceMappingURL=useAppConfig.js.map